@@ -35,6 +35,11 @@ class TestEsLogger(object):
             'get_build_artifact': 'jenkins_url/job/job_name/1/artifact/1',
             'get_build_stages': 'jenkins_url/job/job_name/1/wfapi/describe/'}
 
+    def tearDown(self):
+        ExtensionManager.ENTRY_POINT_CACHE = {}
+        mgr = ExtensionManager(namespace='es_logger.plugins.event_target', invoke_on_load=False)
+        mgr.names()
+
     @unittest.mock.patch.dict(
         'os.environ', {'JENKINS_URL': 'jenkins_url', 'JENKINS_USER': 'jenkins_user',
                        'JENKINS_PASSWORD': 'jenkins_password', 'ES_JOB_NAME': 'es_job_name',
@@ -138,14 +143,25 @@ class TestEsLogger(object):
                            "{} returned {} not {}".format(getter.__name__, getter(), param))
 
     def test_get_es_build_number(self):
-        # Recreate the esl to validate parameters aren't set
+        # Recreate the esl to validate parameters aren't set and default is 0
         self.esl = es_logger.EsLogger(1000, ['dummy'])
-        nose.tools.ok_(self.esl.es_build_number == 0,
-                       "self.esl.es_build_number not 0: {}".format(self.esl.es_build_number))
+        nose.tools.ok_(self.esl.es_build_number == '0',
+                       "self.esl.es_build_number not 0: {} ({})".format(
+                        self.esl.es_build_number, type(self.esl.es_build_number)))
+        es_build_number = '999'
+        # Validate correct value from env
+        with unittest.mock.patch.dict('os.environ', {'ES_BUILD_NUMBER': es_build_number}):
+            self.esl = es_logger.EsLogger(1000, ['dummy'])
+            nose.tools.ok_(self.esl.get_es_build_number() == es_build_number,
+                           "{} not returning {}, types: {} {}".format(
+                           self.esl.es_build_number, es_build_number,
+                           type(self.esl.es_build_number), type(es_build_number)))
+        # Validate env change doesn't change our object
         with unittest.mock.patch.dict('os.environ', {'ES_BUILD_NUMBER': '1000'}):
-            self.esl.es_build_number = self.esl.get_es_build_number()
-            nose.tools.ok_(self.esl.get_es_build_number() == 1000,
-                           "{} not returning {}".format(self.esl.get_es_build_number, 1000))
+            nose.tools.ok_(self.esl.get_es_build_number() == es_build_number,
+                           "{} not returning {}, types: {} {}".format(
+                           self.esl.es_build_number, es_build_number,
+                           type(self.esl.es_build_number), type(es_build_number)))
 
     @parameterized.expand(['process_console_logs', 'gather_build_data', 'generate_events'])
     def test_get_plugin(self, param):
@@ -273,9 +289,12 @@ es_logger.plugins.event_target:
                            "dummy not in build_data keys: {}".format(
                                self.esl.es_info))
             # SCM correctly processed
-            nose.tools.ok_('repoURL' in self.esl.es_info['build_data'].keys(),
-                           "repoURL not in build_data keys: {}".format(
-                               self.esl.es_info['build_data']))
+            nose.tools.ok_(len(self.esl.es_info['build_data']['scm_data']) == 1,
+                           "Wrong number of elements in scm_data: {}".format(
+                           len(self.esl.es_info['build_data']['scm_data'])))
+            nose.tools.ok_(self.esl.es_info['build_data']['scm_data'][0]['name'] == "repoURL",
+                           "Wrong name for scm_data first element: {} not repoURL".format(
+                           self.esl.es_info['build_data']['scm_data'][0]['name']))
 
     def test_get_build_data_config_error(self):
         # Recreate the esl to validate parameters aren't set
@@ -336,9 +355,12 @@ es_logger.plugins.event_target:
                            "dummy not in build_data keys: {}".format(
                                self.esl.es_info))
             # SCM correctly processed
-            nose.tools.ok_('repoURL' in self.esl.es_info['build_data'].keys(),
-                           "repoURL not in build_data keys: {}".format(
-                               self.esl.es_info['build_data']))
+            nose.tools.ok_(len(self.esl.es_info['build_data']['scm_data']) == 1,
+                           "Wrong number of elements in scm_data: {}".format(
+                           len(self.esl.es_info['build_data']['scm_data'])))
+            nose.tools.ok_(self.esl.es_info['build_data']['scm_data'][0]['name'] == "repoURL",
+                           "Wrong name for scm_data first element: {} not repoURL".format(
+                           self.esl.es_info['build_data']['scm_data'][0]['name']))
 
     def test_get_pipeline_job_type_script(self):
         script = "org.jenkinsci.plugins.workflow.cps.CpsFlowDefinition"
